load_cohort: Load dataframe clinical info and optional RNASeq and CNV data

Description Usage Arguments Value

Description

Load dataframe clinical info and optional RNASeq and CNV data

Usage

1
2
load_cohort(cancer, data.dir, genes = NULL, include.cnv = TRUE,
  include.rna = TRUE, file = NULL)

Arguments

cancer

TCGA study (use acronym i.e. SKCM)

data.dir

Directory where the data files are stored

genes

Genes to include in dataframe. NULL loads all genes

include.cnv

Whether to load copy number data

include.rna

Whether to load rnaseq data

file

Filename of the file containing clinical data

Value

Dataframe where each row is a patient sample with columns containing clinical info as well as optional RNASeq/CNV data. All patients have complete Overall Survival data. Solid Tissue Normal samples are not included.


tjbencomo/TBmisc documentation built on May 16, 2019, 4:10 a.m.