Description Usage Arguments Value
Split protein sequence variant column into individual columns Divides column containing protein sequence variants into unique reference, position, and variant columns.
1 | split_aachange(df, column = "aachange")
|
df |
dataframe with protein sequence variant column |
column |
name of the column to split in df |
updated df with reference_aa, position_aa, and alternate_aa columns
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.