Description Usage Arguments Value
Load dataframe clinical info and optional RNASeq and CNV data
1 2 |
cancer |
TCGA study (use acronym i.e. SKCM) |
data.dir |
Directory where the data files are stored |
genes |
Genes to include in dataframe. NULL loads all genes |
include.cnv |
Whether to load copy number data |
include.rna |
Whether to load rnaseq data |
file |
Filename of the file containing clinical data |
Dataframe where each row is a patient sample with columns containing clinical info as well as optional RNASeq/CNV data. All patients have complete Overall Survival data. Solid Tissue Normal samples are not included.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.